def pi():
    return(3.1415)


def add_two_numbers(num1, num2):
    return(num1 + num2)


def subtract_two_numbers(num1, num2):
    return(num1 - num2)


def multiply_two_numbers(num1, num2):
    return(num1 * num2)


def divide_two_numbers(num1, num2):
    return(num1 / num2)


def the_power_of(num1, power):
    return(num1**power)


def sqrt(num):
    if(num < 0):
        return()
    else:
        return(num**0.5)


def f_to_c(temp):
    return((temp - 32) / 1.8)


def c_to_f(temp):
    return((temp * 1.8) + 32)
